@@ -14,8 +14,7 @@ import (
 )
 
 func init() {
-	lang.GoFunctions["tmp"] = cmdTempFile
-	//lang.DefineFunction("tmp", cmdTempFile, types.Any, types.String)
+	lang.DefineMethod("tmp", cmdTempFile, types.Any, types.String)
 }
 
 func cmdTempFile(p *lang.Process) error {
